@@ -16,6 +16,8 @@ isPrintLog = False
 client_id = str(int(time.time() * 1000))
 topic_list_str_pub = ''
 topic_list_str_sub = ''
+isReconnect = False
+mqtt_thread = None
 
 
 def setServerUrl(url='127.0.0.1', port=1883, clientID=str(int(time.time() * 1000))):
@@ -33,24 +35,34 @@ def setMqttLog(PrintLog=False):
 class Dxr_url_port:
     pass
 
+
 def get_cond(topic):
     global callback_dit
-    if not  isinstance(topic, str):
+    if not isinstance(topic, str):
         topic = topic.topic
     if topic not in callback_dit:
         Dxr_Subscriber(topic, None)
     return callback_dit[topic]['cond']
 
+
 def on_connect(client, userdata, flags, rrc):
-    global rc
+    global rc, isReconnect, mqttc
     rc = rrc
     print("Connected with result code " + str(rc))
+    if isReconnect:
+        # 获取callback_dit中的所有topic,键
+        keys = callback_dit.keys()
+        # 重新订阅
+        for item in keys:
+            client.unsubscribe(item)
+            client.subscribe(item, 0)
 
 
 # 一旦订阅到消息，回调此方法
 def on_message(client, obj, msg):
     global callback_dit
     topic = msg.topic
+    print(f'on_message topic={topic}')
     try:
         # threading.Thread(target=callback, args=(topic, msg, client), daemon=True).start()
         callback(topic, msg, client)
@@ -77,7 +89,7 @@ def on_message(client, obj, msg):
 def callback(topic, msg, client):
     global callback_dit
     msg = str(msg.payload.decode("utf-8"))
-    while type(msg) is str:
+    if type(msg) is str:
         msg = json.loads(msg)
     if topic not in callback_dit:
         callback_dit[topic] = {'func': None, 'cond': threading.Event(), 'msg': None}
@@ -86,7 +98,8 @@ def callback(topic, msg, client):
     cond.set()
     cond.clear()
     if callback_dit[topic]['func'] is not None:
-        callback_dit[topic]['func'](msg, topic)
+        func = callback_dit[topic]['func']
+        func(msg, topic)
 
 
 # 一旦订阅成功，回调此方法
@@ -102,8 +115,15 @@ def on_log(mqttc, obj, level, string):
         print(string)
 
 
+def on_disconnect(client, userdata, rrc):
+    global rc, isReconnect, mqttc
+    rc = rrc
+    isReconnect = True
+    print("Disconnected with result code " + str(rc))
+
+
 def Mqtt():
-    global mqttc, server_url, server_port, client_id
+    global mqttc, server_url, server_port, client_id, mqtt_thread
     if mqttc is None:
         try:
             # 新建mqtt客户端，默认没有clientid，clean_session=True, transport="tcp"
@@ -112,12 +132,13 @@ def Mqtt():
             mqttc.on_message = on_message
             mqttc.on_connect = on_connect
             mqttc.on_subscribe = on_subscribe
+            mqttc.on_disconnect = on_disconnect
             mqttc.on_log = on_log
             # 连接broker，心跳时间为60s
-            mqttc.connect(server_url, server_port, 60)
+            mqttc.connect(server_url, server_port, 5)
             # 订阅该主题，QoS=0
-            t = threading.Thread(target=mqttc.loop_forever, daemon=True)
-            t.start()
+            mqtt_thread = threading.Thread(target=mqttc.loop_forever, daemon=True)
+            mqtt_thread.start()
             return mqttc
         except Exception as ex:
             print(ex)
@@ -126,15 +147,27 @@ def Mqtt():
         return mqttc
 
 
+def get_mqtt_status():
+    global mqttc
+    if mqttc is None:
+        return False
+    else:
+        if mqttc.is_connected():
+            return True
+        else:
+            return False
+
+
 class Dxr_Subscriber:
     def __init__(self, topic, callback):
-        global callback_dit, topic_list_str_pub, topic_list_str_sub
-        self.mqttc = Mqtt()
+        global callback_dit, topic_list_str_pub, topic_list_str_sub, mqttc
+        if mqttc is None:
+            mqttc = Mqtt()
         if isinstance(topic, str):
-            self.mqttc.subscribe(topic)
+            mqttc.subscribe(topic)
             self.topic = topic
         else:
-            self.mqttc.subscribe(topic.topic)
+            mqttc.subscribe(topic.topic)
             self.topic = topic.topic
         self.callback = callback
         if self.topic not in callback_dit:
@@ -145,12 +178,13 @@ class Dxr_Subscriber:
         topic_list_str_sub = client_id + '_sub:\n'
         for item in callback_dit.keys():
             topic_list_str_sub = '' + topic_list_str_sub + item + '\n'
-        self.mqttc.publish('/topic/' + client_id, retain=True, payload=topic_list_str_pub + topic_list_str_sub)
+        if mqttc is not None:
+            if mqttc.is_connected():
+                mqttc.publish('/topic/' + client_id, retain=True, payload=topic_list_str_pub + topic_list_str_sub)
 
 
 # 定义一个订阅者类的解释器
 class dxr_subscriber:
-
     def __init__(self, msg):
         # 如果msg的类型是str,则将msg赋值给self.topic
         if isinstance(msg, str):
@@ -167,28 +201,40 @@ class dxr_subscriber:
 
 class Dxr_Publisher:
     def __init__(self, topic):
-        global publish_dit, topic_list_str_pub, topic_list_str_sub, callback_dit
+        global publish_dit, topic_list_str_pub, topic_list_str_sub, callback_dit, mqttc
+        if mqttc is None:
+            mqttc = Mqtt()
         if isinstance(topic, str):
             self.topic = topic
             self.data_type = None
         else:
             self.topic = topic.topic
             self.data_type = topic
-        # 新建mqtt客户端，默认没有clientid，clean_session=True, transport="tcp"
-        self.mqttc = Mqtt()
         if self.topic not in publish_dit:
             publish_dit.append(self.topic)
         topic_list_str_pub = client_id + '_pub:\n'
         for item in publish_dit:
             topic_list_str_pub = '' + topic_list_str_pub + item + '\n'
-        self.mqttc.publish('/topic/' + client_id, retain=True, payload=topic_list_str_pub + topic_list_str_sub)
+        if mqttc is not None:
+            if mqttc.is_connected():
+                mqttc.publish('/topic/' + client_id, retain=True, payload=topic_list_str_pub + topic_list_str_sub)
 
     def publish(self, msg):
-        if self.data_type:
-            self.mqttc.publish(self.topic, msg.get_json(), qos=0)
-        else:
-            self.mqttc.publish(self.topic, json.dumps(msg), qos=0)
-    
+        global mqttc
+        if mqttc is None:
+            mqttc = Mqtt()
+        try:
+            if self.data_type:
+                if mqttc is not None:
+                    if mqttc.is_connected():
+                        mqttc.publish(self.topic, msg.get_json(), qos=0)
+            else:
+                if mqttc is not None:
+                    if mqttc.is_connected():
+                        mqttc.publish(self.topic, json.dumps(msg), qos=0)
+        except Exception as ex:
+            print(f'publish error: {ex}')
+
     '''
     使用await_publish来实现消息闭环
     await_publish(msg, timeout, topic)
@@ -197,15 +243,22 @@ class Dxr_Publisher:
         timeout 不指定的时候，为一直等待设定话题的消息，指定后超时时间中未收到消息，会接收到一个None消息
         topic 为指定闭环消息的话题类型，如果不指定，则默认为原话题类型后追加'_response',可以传递字符串类型的话题，也可以传递消息类型
     }
-    '''      
+    '''
+
     def await_publish(self, msg, timeout=None, topic=None):
-        global callback_dit
+        global callback_dit, mqttc
+        if mqttc is None:
+            mqttc = Mqtt()
         if self.data_type:
-            self.mqttc.publish(self.topic, msg.get_json(), qos=0)
+            if mqttc is not None:
+                if mqttc.is_connected():
+                    mqttc.publish(self.topic, msg.get_json(), qos=0)
         else:
-            self.mqttc.publish(self.topic, json.dumps(msg), qos=0)
+            if mqttc is not None:
+                if mqttc.is_connected():
+                    mqttc.publish(self.topic, json.dumps(msg), qos=0)
         await_topic = None
-        if topic is None: 
+        if topic is None:
             await_topic = self.topic + '_response'
         else:
             if isinstance(topic, str):
@@ -223,13 +276,13 @@ class Dxr_Publisher:
         else:
             cond.wait(timeout)
         return callback_dit[await_topic]['msg']
-        
 
 
 class Dxr_UnSubscriber:
     def __init__(self, topic):
-        global callback_dit
+        global callback_dit, mqttc
+        if mqttc is None:
+            mqttc = Mqtt()
         self.topic = topic
-        self.mqttc = Mqtt()
-        self.mqttc.unsubscribe(self.topic)
+        mqttc.unsubscribe(self.topic)
         callback_dit.pop(self.topic)
