@@ -594,7 +594,13 @@ class get_voltage_response(msg):
     {
         "msg":{
             "voltage":[80000,0],//电池1电压，电池2电压,单位mv
-            "current":[1000,0] //电池1电流,电池2电流
+            "current":[1000,0], //电池1电流,电池2电流
+            "temperature":0, //当前温度,int类型
+            "now_percent":0, //剩余电量百分比,单位%,int类型
+            "max_capacity":0, //满电容量,单位0.1AH,int类型
+            "now_capacity":0, //当前剩余容量,单位0.1AH,int类型	
+            "state":0, //电池状态，参考各电池状态说明表
+            "charging_state":0, //充电状态	0:未充电 1:充电
         }
     }
     """
@@ -605,6 +611,13 @@ class get_voltage_response(msg):
             super().__init__()
             self.voltage = ""  # list型
             self.current = ""  # list型
+            self.temperature = ""  # int型
+            self.now_percent = ""  # int型
+            self.max_capacity = ""  # int型
+            self.now_capacity = ""  # int型
+            self.state = ""  # int型
+            self.charging_state = ""  # int型
+            
 
     def __init__(self):
         super().__init__()
@@ -1156,6 +1169,18 @@ class hardware_ctrl_response(msg):
                 "BackNumber":1, //uint8_t,后侧超声数量
                 "SideNumber":1, //uint8_t,左右侧超声数量
                 "GearBoxDirection":1, //uint8_t,减速器转向 0:反向 1:正向
+                "PSC": int(),  //PWM分频系数
+                "PER": int(),  //PWM自动重载值 T=(PSC-1)/(PER-1)/72000 ms
+                "Retained1": int(),  //备用
+                "Retained2": int(),  //备用
+                "Retained3": int(),  //备用
+                "Retained4": int(),  //备用
+                "Retained5": int(),  //备用
+                "Retained6": int(),  //备用
+                "Retained7": int(),  //备用
+                "Retained8": int(),  //备用
+                "Retained9": int(),  //备用
+                "Retained10": int(),  //备用
             }
         }
     }
@@ -1175,6 +1200,18 @@ class hardware_ctrl_response(msg):
             self.BackNumber = ""  # uint8_t,
             self.SideNumber = ""  # uint8_t,
             self.GearBoxDirection = ""  # uint8_t,
+            self.PSC = ""  # uint8_t
+            self.PER = ""  # uint8_t
+            self.Retained1 = ""
+            self.Retained2 = ""
+            self.Retained3 = ""
+            self.Retained4 = ""
+            self.Retained5 = ""
+            self.Retained6 = ""
+            self.Retained7 = ""
+            self.Retained8 = ""
+            self.Retained9 = ""
+            self.Retained10 = ""
             
     def __init__(self):
         super().__init__()
